@@ -1,5 +1,5 @@
 multiStart <- function(par, fn, gr = NULL, action = c("solve", "optimize"), 
-    method = c(2, 3, 1), control = list(), quiet=FALSE, details = FALSE, ...) 
+    method = c(2, 3, 1), project=NULL, projectArgs=NULL, control = list(), quiet=FALSE, details = FALSE, ...) 
     {
     if (is.null(dim(par))) 
         par <- matrix(par, nrow = 1, ncol = length(par))
@@ -18,7 +18,7 @@ multiStart <- function(par, fn, gr = NULL, action = c("solve", "optimize"),
                 control = control, quiet=quiet, ...), silent=TRUE)
         if (action == "optimize") 
             ans <- try(BBoptim(par[k, ], fn = fn, gr = gr, method = method, 
-                control = control, quiet=quiet, ...), silent=TRUE)
+                control = control, project=project, projectArgs=projectArgs, quiet=quiet, ...), silent=TRUE)
         if (inherits(ans, "try-error")) next
         cvg[k] <- (ans$convergence == 0)
         values[k] <- if (action == "solve") ans$residual else ans$value
